@@ -84,7 +84,7 @@
 #include "multiqueue.h"
 #include "queue.h"
 #include "tee.h"
-#include "typefind.h"
+#include "typefindelement.h"
 #include "adder.h"
 #include "alsamixer.h"
 #include "alsasink.h"
@@ -266,9 +266,9 @@ GType gst_time_overlay_get_type(void);
 #endif //GSTREAMERMM_PLUGIN_TIMEOVERLAY
 GType gst_tuner_channel_get_type(void);
 GType gst_tuner_norm_get_type(void);
-#ifdef GSTREAMERMM_PLUGIN_TYPEFIND
+#ifdef GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
 GType gst_type_find_element_get_type(void);
-#endif //GSTREAMERMM_PLUGIN_TYPEFIND
+#endif //GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
 #ifdef GSTREAMERMM_PLUGIN_VIDEORATE
 GType gst_video_rate_get_type(void);
 #endif //GSTREAMERMM_PLUGIN_VIDEORATE
@@ -455,9 +455,9 @@ namespace Gst {  class TimeOverlay_Class { public: static Glib::ObjectBase* wrap
 #endif //GSTREAMERMM_PLUGIN_TIMEOVERLAY
 namespace Gst {  class TunerChannel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class TunerNorm_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifdef GSTREAMERMM_PLUGIN_TYPEFIND
-namespace Gst {  class TypeFind_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif //GSTREAMERMM_PLUGIN_TYPEFIND
+#ifdef GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
+namespace Gst {  class TypeFindElement_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
 #ifdef GSTREAMERMM_PLUGIN_VIDEORATE
 namespace Gst {  class VideoRate_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //GSTREAMERMM_PLUGIN_VIDEORATE
@@ -644,9 +644,9 @@ void wrap_init()
 #endif //GSTREAMERMM_PLUGIN_TIMEOVERLAY
   Glib::wrap_register(gst_tuner_channel_get_type(), &Gst::TunerChannel_Class::wrap_new);
   Glib::wrap_register(gst_tuner_norm_get_type(), &Gst::TunerNorm_Class::wrap_new);
-#ifdef GSTREAMERMM_PLUGIN_TYPEFIND
-  Glib::wrap_register(gst_type_find_element_get_type(), &Gst::TypeFind_Class::wrap_new);
-#endif //GSTREAMERMM_PLUGIN_TYPEFIND
+#ifdef GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
+  Glib::wrap_register(gst_type_find_element_get_type(), &Gst::TypeFindElement_Class::wrap_new);
+#endif //GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
 #ifdef GSTREAMERMM_PLUGIN_VIDEORATE
   Glib::wrap_register(gst_video_rate_get_type(), &Gst::VideoRate_Class::wrap_new);
 #endif //GSTREAMERMM_PLUGIN_VIDEORATE
@@ -821,9 +821,9 @@ void wrap_init()
 #endif //GSTREAMERMM_PLUGIN_TIMEOVERLAY
   Gst::TunerChannel::get_type();
   Gst::TunerNorm::get_type();
-#ifdef GSTREAMERMM_PLUGIN_TYPEFIND
-  Gst::TypeFind::get_type();
-#endif //GSTREAMERMM_PLUGIN_TYPEFIND
+#ifdef GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
+  Gst::TypeFindElement::get_type();
+#endif //GSTREAMERMM_PLUGIN_TYPEFINDELEMENT
 #ifdef GSTREAMERMM_PLUGIN_VIDEORATE
   Gst::VideoRate::get_type();
 #endif //GSTREAMERMM_PLUGIN_VIDEORATE
